@@ -1,26 +1,9 @@
 """
 Constants and paths.
 """
+from enum import Enum
 from pathlib import Path
 
-# Master module name
-MODULE_NAME = "mypy_boto3"
-
-# aiobotocore module name
-AIOBOTOCORE_MODULE_NAME = "types_aiobotocore"
-
-# PyPI module name
-PYPI_NAME = "mypy-boto3"
-
-# boto3-stubs lite PyPI module name
-BOTO3_STUBS_LITE_PYPI_NAME = "boto3-stubs-lite"
-
-# types-aiobotocore lite PyPI module name
-AIOBOTOCORE_STUBS_LITE_PYPI_NAME = "types-aiobotocore-lite"
-
-# aiobotocore PyPI module name
-AIOBOTOCORE_PYPI_NAME = "types-aiobotocore"
-
 # Random region to initialize services
 DUMMY_REGION = "us-west-2"
 
@@ -36,20 +19,9 @@ BOTOCORE_STUBS_STATIC_PATH = Path(__file__).parent / "botocore_stubs_static"
 # Static *.pyi files for aiobotocore-stubs
 AIOBOTOCORE_STUBS_STATIC_PATH = Path(__file__).parent / "aiobotocore_stubs_static"
 
-# Boto3 stubs module name
-BOTO3_STUBS_NAME = "boto3-stubs"
-
-# Botocore stubs module name
-BOTOCORE_STUBS_NAME = "botocore-stubs"
-
-# aiobotocore stubs module name
-AIOBOTOCORE_STUBS_NAME = "aiobotocore-stubs"
-
 # Max line length for boto3 docs
 LINE_LENGTH = 100
 
-# type defs module name
-TYPE_DEFS_NAME = "type_defs"
 
 # Main logger name
 LOGGER_NAME = "mypy_boto3_builder"
@@ -59,3 +31,19 @@ PROG_NAME = "mypy_boto3_builder"
 
 # builder package name
 PACKAGE_NAME = "mypy-boto3-builder"
+
+
+class Product(Enum):
+    """
+    Product choice for CLI.
+    """
+
+    boto3 = "boto3"
+    boto3_services = "boto3-services"
+    boto3_docs = "boto3-docs"
+    aiobotocore = "aiobotocore"
+    aiobotocore_services = "aiobotocore-services"
+    aiobotocore_docs = "aiobotocore-docs"
+
+    def __str__(self) -> str:
+        return self.name
