@@ -1,6 +1,8 @@
 """
 Getters for boto3 client and resource from session.
 """
+from functools import cache
+
 from boto3.exceptions import ResourceNotExistsError
 from boto3.resources.base import ServiceResource as Boto3ServiceResource
 from boto3.session import Session
@@ -9,6 +11,7 @@ from botocore.client import BaseClient
 from mypy_boto3_builder.service_name import ServiceName
 
 
+@cache
 def get_boto3_client(session: Session, service_name: ServiceName) -> BaseClient:
     """
     Get boto3 client from `session`.
@@ -23,6 +26,7 @@ def get_boto3_client(session: Session, service_name: ServiceName) -> BaseClient:
     return session.client(service_name.boto3_name)  # type: ignore
 
 
+@cache
 def get_boto3_resource(session: Session, service_name: ServiceName) -> Boto3ServiceResource | None:
     """
     Get boto3 resource from `session`.
