@@ -21,7 +21,7 @@ class ServicePackagePostprocessor:
 
     def __init__(self, package: ServicePackage) -> None:
         self.package = package
-        self.docs_package_name = self.package.docs_package_name
+        self.docs_package_name = self.package.data.PYPI_NAME
 
     def generate_docstrings(self) -> None:
         """
@@ -68,7 +68,7 @@ class ServicePackagePostprocessor:
             ]
             paginate_method = paginator.get_method("paginate")
             assert isinstance(paginate_method.return_type, TypeSubscript)
-            paginate_method.return_type.parent = Type.AsyncIterable
+            paginate_method.return_type.parent = Type.AsyncIterator
 
     def _make_async_waiters(self) -> None:
         for waiter in self.package.waiters:
