@@ -70,7 +70,8 @@ class ServicePackage(Package):
                 old_literal = found[literal.name]
                 if not literal.is_same(old_literal):
                     raise ValueError(
-                        f"Duplicate literal: {literal.name} {literal.children} != {old_literal.children}"
+                        f"Duplicate literal: {literal.name} {literal.children} !="
+                        f" {old_literal.children}"
                     )
 
         return list(sorted(found.values()))
@@ -336,9 +337,26 @@ class ServicePackage(Package):
 
     def extend_literals(self, service_names: Iterable[ServiceName]) -> None:
         """
-        Add `ServiceName`, `PaginatorName` and `WaiterName` literals.
+        Add extra literals.
+
+        - `<Class>ServiceName`
+        - `ServiceName`
+        - `ResourceServiceName`
+        - `PaginatorName`
+        - `WaiterName`
         """
+        self.literals.append(
+            TypeLiteral(
+                f"{self.service_name.class_name}ServiceName", [self.service_name.boto3_name]
+            )
+        )
         self.literals.append(TypeLiteral("ServiceName", [i.boto3_name for i in service_names]))
+        self.literals.append(
+            TypeLiteral(
+                "ResourceServiceName",
+                [i.boto3_name for i in service_names if i.has_service_resource],
+            )
+        )
 
         paginator_names = [paginator.operation_name for paginator in self.paginators]
         if paginator_names:
